Developer Information
=====================

The following information may be useful for those wishing to extend LinchPin.

.. toctree::
   :maxdepth: 1

   libdocs
   writing_provider


.. seealso::

    `User Mailing List <https://www.redhat.com/mailman/listinfo/linchpin>`_
        Subscribe and participate. A great place for Q&A
    `irc.freenode.net <http://irc.freenode.net>`_
        #linchpin IRC chat channel
